package a.cardiscover;

import android.content.Context;
import android.util.Log;
import com.google.android.gms.maps.model.LatLng;
import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;


class ControladorDatos {

     void CargaInicial (Context context) {
        // Carga inicial del vehiculo vinculado y su posicion
        String fichero = "posicion";
        // Inicialización receiveString a vacio como punto de partida para la comparativa posterior.
        String receiveString = "";
        String [] temporal;
        try {
            InputStream inputStream = context.openFileInput(fichero);

            if ( inputStream != null ) {
                InputStreamReader inputStreamReader = new InputStreamReader(inputStream);
                BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
                receiveString = bufferedReader.readLine();
                inputStream.close();
            }
        }
        catch (FileNotFoundException e) {
            Log.e("login activity","No existe fichero de Vehiculo " + e.toString());
        } catch (IOException e) {
            Log.e("login activity", "Can not read file: " + e.toString());
        }
            // Se revisa si hay contenido en el String lo que indica que hay datos de posicion o vehiculo
         if (!receiveString.equals("")) {
             // Se particiona el string cargado con el caracter ; buscando vehiculo, latitud y longitud
             temporal = receiveString.split(";");
             LatLng posicion = null;
             // Se controla si hay posicion definida.
             if (temporal.length > 3) {
                 posicion = new LatLng(Double.valueOf(temporal[2].replace(",", ".")), Double.valueOf(temporal[3].replace(",", ".")));
             }
             // Se crea un objeto vehiculo con el nombre del vehiculo y su posicion si existe o bien null.
             Vehiculo VehiculoActual = new Vehiculo(temporal[0], temporal[1], posicion);
         }
    }

    static void GuardarVehiculoActual (String Vehiculo, String Adress , Context ctx) {

        // Acceso a la funcion desde VINCULACIÓN
        // Se guarda el vehiculo seleccionado en fichero posicion
        String fichero = "posicion";
        FileOutputStream outputStream;
        try {
            outputStream = ctx.openFileOutput(fichero, Context.MODE_PRIVATE);
            // Se trunca el fichero para borrar posibles datos anteriores
            String Output=Vehiculo.concat(";").concat(Adress);
            outputStream.getChannel().truncate(0);
            outputStream.getChannel().force(true);
            outputStream.getChannel().lock();
            outputStream.write(Output.getBytes());
            outputStream.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    static void GuardarPosicion (String nombre, String Address, LatLng Posicion, Context context)  {

        // Acceso a la funcion desde POSICION
        // Se guarda el vehiculo y la posicion del vehiculo actual en fichero posicion
        String fichero = "posicion";
        FileOutputStream outputStream;
        // Se trunca la posicion a 4 decimales
        String Latitud = String.format("%1$.4f",Posicion.latitude) ;
        String Longitud = String.format("%1$.4f", Posicion.longitude) ;
        // Se concatena todo en un solo string.
        String resultado = nombre.concat(";").concat(Address).concat(";").concat((Latitud).concat(";").concat(Longitud));

        try {
            outputStream = context.openFileOutput(fichero, Context.MODE_PRIVATE);
            // Se trunca el fichero para borrar posibles datos anteriores
            outputStream.getChannel().truncate(0);
            outputStream.getChannel().force(true);
            outputStream.getChannel().lock();
            outputStream.write(resultado.getBytes());
            outputStream.close();
        } catch (Exception e) {
            e.printStackTrace();
        }

        // Se salva la posicion en el fichero de historicos
        resultado = nombre.concat(";").concat((Latitud).concat(";").concat(Longitud));
        String fichero2 = "historico";
        FileOutputStream outputStream2;
        String separator = System.getProperty("line.separator");
        Calendar c = Calendar.getInstance();
        String dia = String.valueOf(c.get(Calendar.DAY_OF_MONTH));
        // Se corrige el mes que aparece con 0 como enero
        String mes = String.valueOf(c.get(Calendar.MONTH)+1);
        String anyo = String.valueOf( c.get(Calendar.YEAR));
        String resultado2=resultado.concat(";").concat(dia).concat("/").concat(mes).concat("/").concat(anyo).concat(separator);
        try {
            outputStream2 = context.openFileOutput(fichero2, Context.MODE_APPEND);
            outputStream2.write(resultado2.getBytes());
            outputStream2.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    String [] CargarHistorico (Context context){

        // Acceso a la función desde HISTORIAL
        // Lectura de los datos del fichero historico
        String fichero = "historico";
        String [] ret= null;
        try {
            InputStream inputStream = context.openFileInput(fichero);
            if ( inputStream != null ) {
                InputStreamReader inputStreamReader = new InputStreamReader(inputStream);
                BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
                String receiveString;
                List<String> lines = new ArrayList<>();
              while ( (receiveString = bufferedReader.readLine()) != null ) {
                    lines.add(receiveString);
                }
                inputStream.close();
                ret = lines.toArray(new String[0]);
            }
        }
        catch (FileNotFoundException e) {
            Log.e("login activity", "File not found: " + e.toString());
        } catch (IOException e) {
            Log.e("login activity", "Can not read file: " + e.toString());
        }
        return ret;

    }

    static void dispositivoSeleccionado (String Vh, String Address, Context ctx) {

        //Se guarda en memoria en la classe Vehiculo el dispositivo seleccionado
        // Inicialmente no hay ubicación, se define a null
        Vehiculo V = new Vehiculo (Vh,Address, null);
        // Se marca el vehiculo como el último vinculado
        V.setUltimo(ctx);
        // Se guardan los datos a fichero
        GuardarVehiculoActual(Vh,Address,ctx);
    }
}
