package a.cardiscover;
import android.content.Context;
import android.content.DialogInterface;
import android.content.pm.PackageManager;
import android.location.Location;
import android.os.Build;
import android.support.v4.app.ActivityCompat;
import android.support.v4.app.FragmentActivity;
import android.os.Bundle;
import android.support.v4.content.ContextCompat;
import android.Manifest;
import android.support.v7.app.AlertDialog;
import android.widget.Toast;
import com.google.android.gms.appindexing.AppIndex;
import com.google.android.gms.common.ConnectionResult;
import com.google.android.gms.common.api.GoogleApiClient;
import com.google.android.gms.location.LocationListener;
import com.google.android.gms.location.LocationServices;
import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.MarkerOptions;
import com.google.android.gms.maps.model.BitmapDescriptorFactory;

public class encontrarVehiculo extends FragmentActivity implements OnMapReadyCallback,
        GoogleApiClient.ConnectionCallbacks,
        GoogleApiClient.OnConnectionFailedListener,
        LocationListener {

    // Definición del mapa a usar
    private GoogleMap mMap2;
    private GoogleApiClient client;
    // Uso de la Api de google para ubicación en el mapa
    GoogleApiClient mGoogleApiClient;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_encontrar_vehiculo);
        SupportMapFragment mapFragment = (SupportMapFragment) getSupportFragmentManager()
                .findFragmentById(R.id.map2);
        mapFragment.getMapAsync(this);
        client = new GoogleApiClient.Builder(this).addApi(AppIndex.API).build();
    }


    @Override
    public void onMapReady(GoogleMap googleMap2) {
        mMap2 = googleMap2;
        // Control de la versión y la necesidad de solicitar permisos de acceso a la ubicación
       if (android.os.Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            if (ContextCompat.checkSelfPermission(this,
                    Manifest.permission.ACCESS_FINE_LOCATION)
                    == PackageManager.PERMISSION_GRANTED) {
                buildGoogleApiClient();
                mMap2.setMyLocationEnabled(true);
            } else {
                checkLocationPermission();
            }
        }
        else {
            buildGoogleApiClient();
            mMap2.setMyLocationEnabled(true);
        }
        // Se controla la existencia de un vehiculo vinculado
        if (Vehiculo.Vehiculo_Actual!=null) {
            // Se obtiene la posición del vehiculo vinculado
            LatLng posicionVehiculo = Vehiculo.Vehiculo_Actual.getPosicion();
            // Se verifica que la posición del vehiculo vinculado no es null, lo que indicaría que aún no existe posición
            if (posicionVehiculo != null) {
                // se marca la posición del vehiculo con el título "Vehiculo"
                MarkerOptions posicionVh = new MarkerOptions()
                        .position(posicionVehiculo)
                        .title(Vehiculo.Vehiculo_Actual.getNombre());
                // Se modifica el icono a visualizar por el de un coche
                posicionVh.icon(BitmapDescriptorFactory.fromResource(R.drawable.car));
                mMap2.addMarker(posicionVh);
                // Se centra el mapa y se realiza un zoom para mejorar la visualización
                mMap2.moveCamera(CameraUpdateFactory.newLatLng(posicionVehiculo));
                mMap2.animateCamera(CameraUpdateFactory.zoomTo(16));
            }
            else {
                // si no existe ubicación se muestra notificación al usuario
                Context ctx = getApplicationContext();
                CharSequence text = "NO EXISTE UBICACIÓN";
                int duration = Toast.LENGTH_SHORT;
                Toast toast = Toast.makeText(ctx, text, duration);
                toast.show();
            }
        }
        else {
            // si no existe dispositivo vinculado se muestra notificación al usuario
            Context ctx = getApplicationContext();
            CharSequence text = "NO EXISTE DISPOSITIVO";
            int duration = Toast.LENGTH_SHORT;
            Toast toast = Toast.makeText(ctx, text, duration);
            toast.show();
            }
    }

    protected synchronized void buildGoogleApiClient() {
        mGoogleApiClient = new GoogleApiClient.Builder(this)
                .addConnectionCallbacks(this)
                .addOnConnectionFailedListener(this)
                .addApi(LocationServices.API)
                .build();
        mGoogleApiClient.connect();
    }

    @Override
    public void onConnected(Bundle bundle) {
    }

    @Override
    public void onConnectionSuspended(int i) {}

    @Override
    public void onConnectionFailed(ConnectionResult connectionResult) {}

    //@Override
   public void onLocationChanged(Location location)
    {
    }

    public static final int MY_PERMISSIONS_REQUEST_LOCATION = 99;
    // funcion para la definión y requerimiento de los permisos de localización
    private void checkLocationPermission() {
        if (ContextCompat.checkSelfPermission(this, Manifest.permission.ACCESS_FINE_LOCATION)
                != PackageManager.PERMISSION_GRANTED) {
            if (ActivityCompat.shouldShowRequestPermissionRationale(this,
                    Manifest.permission.ACCESS_FINE_LOCATION)) {
                new AlertDialog.Builder(this)
                        .setTitle("Se necesitan permisos de localizacion")
                        .setMessage("Se necesitan permisos de localización, acepte el uso de la funcion de localizacion")
                        .setPositiveButton("OK", new DialogInterface.OnClickListener() {
                            @Override
                            public void onClick(DialogInterface dialogInterface, int i) {
                                ActivityCompat.requestPermissions(encontrarVehiculo.this,
                                        new String[]{Manifest.permission.ACCESS_FINE_LOCATION},
                                        MY_PERMISSIONS_REQUEST_LOCATION );
                            }
                        })
                        .create()
                        .show();
            } else {
                ActivityCompat.requestPermissions(this,
                        new String[]{Manifest.permission.ACCESS_FINE_LOCATION},
                        MY_PERMISSIONS_REQUEST_LOCATION );
            }
        }
    }

    @Override
    public void onRequestPermissionsResult(int requestCode,
                                           String permissions[], int[] grantResults) {
        switch (requestCode) {
            case MY_PERMISSIONS_REQUEST_LOCATION: {
                if (grantResults.length > 0
                        && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
                   if (ContextCompat.checkSelfPermission(this,
                            Manifest.permission.ACCESS_FINE_LOCATION)
                            == PackageManager.PERMISSION_GRANTED) {
                        if (mGoogleApiClient == null) {
                            buildGoogleApiClient();
                        }
                        mMap2.setMyLocationEnabled(true);
                    }
                } else {
                    Toast.makeText(this, "PERMISO DENEGADO", Toast.LENGTH_LONG).show();
                }
            }
        }
    }
}
